@@ -214,7 +214,7 @@ class Manager(object):
         SubElement(Emisor, "Departamento").text = str(self.emisor.state or '')
 
     def build_Receptor(self, Encabezado, type):
-        
+
         Receptor = SubElement(Encabezado, "Receptor")
 
         RECEPTOR_BUILDER = {
@@ -225,7 +225,7 @@ class Manager(object):
             'eResg': self.build_local_receptor,
             'eRem': self.build_local_receptor_rem,
             'eRem_Exp': self.build_exportation_receptor,
-        }          
+        }
         if type == 'eTck':
             RECEPTOR_BUILDER.get(type)(Receptor,Encabezado)
         else:
@@ -250,19 +250,23 @@ class Manager(object):
 
     def build_local_receptor_etck(self, Receptor, Encabezado):
         """
-        Completa los datos del receptor de un eTicket 
-        solo si tienen datos de tipo y número de documento.
-        Si no están esos datos se quita el tag del Receptor. 
+        Completa los datos del receptor de un eTicket.
+        En caso de que el partner receptor no tenga vat entonces 
+        solo se tendra que enviar el nombre del partner.
         :param Receptor: elemento Receptor del xml
         :param Encabezado: elemento Encabezado del xml
         """
         if self.comprobante.partner.vat:
             self.build_local_receptor(Receptor)
         else:
-            Encabezado.remove(Receptor)
+            self.build_local_receptor_for_etck_without_vat(Receptor)
 
-    def build_local_receptor(self, Receptor):
+    def build_local_receptor_for_etck_without_vat(self, Receptor):
+
+        SubElement(Receptor, "RznSocRecep").text = str(self.comprobante.partner.name)
         
+    def build_local_receptor(self, Receptor):
+
         SubElement(Receptor, "TipoDocRecep").text = str(self.comprobante.partner.vat.code or '')
         SubElement(Receptor, "CodPaisRecep").text = str(self.comprobante.partner.country_code or '')
         SubElement(Receptor, self.get_doc_recep_type(self.comprobante.partner.country_code)).text = str(self.comprobante.partner.vat.number or '')
@@ -463,13 +467,18 @@ class Manager(object):
             item_nro += 1
             Item[item_nro] = SubElement(Detalle, "Item")
             SubElement(Item[item_nro], "NroLinDet").text = str(item_nro)
-            if line.invoice_indicator: SubElement(Item[item_nro], "IndFact").text = str(line.invoice_indicator)
+            if hasattr(line, 'cod_item'):
+                CodItem = SubElement(Item[item_nro], "CodItem")
+                SubElement(CodItem, "TpoCod").text = str(line.cod_item.tpo_cod)
+                SubElement(CodItem, "Cod").text = str(line.cod_item.cod)
+            if line.invoice_indicator:
+                SubElement(Item[item_nro], "IndFact").text = str(line.invoice_indicator)
             SubElement(Item[item_nro], "NomItem").text = str(line.description)
             if hasattr(line, 'description_extra'):
                 SubElement(Item[item_nro], "DscItem").text = str(line.description_extra)
             SubElement(Item[item_nro], "Cantidad").text = str(line.quantity)
             SubElement(Item[item_nro], "UniMed").text = str(line.uom_code) if line.uom_code else 'N/A'
-            SubElement(Item[item_nro], "PrecioUnitario").text = self._format_amount(line.unit_price)
+            SubElement(Item[item_nro], "PrecioUnitario").text = self._format_amount(line.unit_price, self.comprobante.decimal_places if hasattr(self.comprobante, "decimal_places") else 2)
             if hasattr(line, 'discount') and hasattr(line, 'discount_amount'):
                 SubElement(Item[item_nro], "DescuentoPct").text = self._format_amount(line.discount)
                 SubElement(Item[item_nro], "DescuentoMonto").text = self._format_amount(line.discount_amount)
@@ -505,8 +514,9 @@ class Manager(object):
         return '{:.3f}'.format(rate)
 
     @staticmethod
-    def _format_amount(rate):
-        return '{:.2f}'.format(rate)
+    def _format_amount(rate, decimal=2):
+        value = '{:.' + str(decimal) + 'f}'
+        return value.format(rate)
 
     def _get_uuid_cfe(self):
         uuid = self.comprobante.uuid if hasattr(self.comprobante, 'uuid') else False
