@@ -130,7 +130,7 @@ class TestUruware(unittest.TestCase):
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
-    
+
     # Ejemplo para e-Factura con cobranza
     def test_eFact_cfe_invoice_receipt(self):
 
@@ -359,6 +359,44 @@ class TestUruware(unittest.TestCase):
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
+    # Ejemplo para e-Ticket para un partner sin vat
+    def test_eTck_cfe_invoice_without_vat(self):
+        # partner factura
+        invoice_partner = objects.Partner("Uruware S.A.")
+        invoice_partner.vat = False
+        invoice_partner.name = 'Uruware S.A.'
+        invoice_partner.city = 'Montevideo'
+        invoice_partner.street = 'Bv.Espana 2579'
+        invoice_partner.country_code = 'UY'
+        invoice_partner.country = 'Uruguay'
+        invoice_partner.email = 'lbaldi@openpyme.com.ar'
+
+        line1 = objects.InvoiceLine(100, invoice_indicator=3)
+        line1.description = "Prueba tasa basica"
+        line1.quantity = 1
+        line1.unit_price = 100
+        line1.tax = 22
+
+        line2 = objects.InvoiceLine(50, invoice_indicator=2)
+        line2.description = "Prueba tasa minima"
+        line2.quantity = 1
+        line2.unit_price = 50
+        line2.tax = 5
+
+        # creamos factura
+        comprobante = objects.Invoice('invoice')
+        comprobante.cfe_code = '101'
+        comprobante.date = '2015-01-31'
+        comprobante.payment_method = 1
+        comprobante.partner = invoice_partner
+        comprobante.cfe_type = 'eTck'
+        comprobante.invoice_lines = [line1, line2]
+        comprobante.currency = 'UYU'
+
+        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
+
     # 6.2.1.1 Ejemplo para e-Ticket
     def test_eTck_cfe_invoice(self):
         # partner factura
@@ -1526,4 +1564,45 @@ class TestUruware(unittest.TestCase):
         msg_second = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
         assert msg_first.get('responseBody').Resp.XmlCfeFirmado == msg_second.get('responseBody').Resp.XmlCfeFirmado
-    
\ No newline at end of file
+
+    def test_eFact_cfe_invoice_three_decimal_places(self):
+
+        # partner factura
+        partner_vat = objects.Vat(215404940014, 2)
+        invoice_partner = objects.Partner("Uruware S.A.")
+        invoice_partner.vat = partner_vat
+        invoice_partner.name = 'Uruware S.A.'
+        invoice_partner.city = 'Montevideo'
+        invoice_partner.street = 'Bv.Espana 2579'
+        invoice_partner.country_code = 'UY'
+        invoice_partner.country = 'Uruguay'
+        invoice_partner.email = 'lbaldi@openpyme.com.ar'
+
+        # creamos linea gravada tasa basica
+        line1 = objects.InvoiceLine(99, invoice_indicator=3)
+        line1.description = "Servicios de desarrollo"
+        line1.quantity = 1
+        line1.unit_price = 99
+        line1.tax = 21.78
+
+        # creamos linea no facturable
+        line2 = objects.InvoiceLine(0.22, invoice_indicator=6)
+        line2.description = "Redondeo"
+        line2.description_extra = "Redondeo Extra"
+        line2.quantity = 1
+        line2.unit_price = 0.22
+
+        # creamos factura
+        comprobante = objects.Invoice('invoice')
+        comprobante.cfe_code = '111'
+        comprobante.date = '2015-01-31'
+        comprobante.payment_method = 1
+        comprobante.partner = invoice_partner
+        comprobante.cfe_type = 'eFact'
+        comprobante.invoice_lines = [line1, line2]
+        comprobante.currency = 'UYU'
+        comprobante.decimal_places = 3
+
+        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
